Task: Wizard of Internet
==========================
This task involves a dialogue dataset between two crowdsource workers.  One of
the agents (called hereafter the *apprentice*) has some interests that wants to
talk about them.  The other agent (*wizard*) has access to internet search and
provides knowledgeable responses to the apprentice.

LICENSE: This dataset has been released under the CC-BY-4.0 License. Please refer to the LICENSE_DOCUMENTATION file in this repository for more information.

See the [project page](https://parl.ai/projects/sea) for more information.

Tags: #Wizard_of_Internet, #All, #ChitChat
